<?php
/**
 * @file
 * Contains \Drupal\onpoint_search\Form\OnPointSettingsForm.
 */

namespace Drupal\onpoint_search\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure OnPoint Search settings for this site.
 */
class OnPointSettingsForm extends ConfigFormBase {
    /** @var string Config settings */
  const SETTINGS = 'onpoint_search.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'onpoint_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    global $base_url;
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();

    $onpoint_path = $form_state->getValue('onpoint_path');

    $path_exists = $onpoint_path ? \Drupal::service('path.alias_storage')->aliasExists($onpoint_path, $langcode, $base_url) : false;

    if (!empty($onpoint_path) && $path_exists) {
      $form_state->setErrorByName('onpoint_path', $this->t('This path is already in use. Please choose a unique path that is not already being used on your site.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['onpoint_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('onpoint_key'),
      '#description' => $this->t('Enter your OnPoint Search API key.'),
      '#required' => TRUE,
      '#size' => 36,
      '#maxlength' => 36,
      '#pattern' => '^([0-9A-Fa-f]{8})-([0-9A-Fa-f]{4})-([0-9A-Fa-f]{4})-([0-9A-Fa-f]{4})-([0-9A-Fa-f]{12})$',
    ];

    $form['onpoint_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Results Page Title'),
      '#default_value' => $config->get('onpoint_title'),
      '#description' => $this->t('Enter the page title for your OnPoint Search results page. Default title is \'Search Results\'.'),
      '#maxlength' => 60,
    ];

    $form['onpoint_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Results Page Path'),
      '#default_value' => $config->get('onpoint_path'),
      '#description' => $this->t('Enter the desired path for the OnPoint Search results page. This must be a unique path that is not already being used on your site. Default path is \'/search-results\'.'),
      '#maxlength' => 60,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration
    $this->configFactory->getEditable(static::SETTINGS)
      // Set the submitted configuration setting
      ->set('onpoint_key', $form_state->getValue('onpoint_key'))
      ->set('onpoint_title', $form_state->getValue('onpoint_title'))
      ->set('onpoint_path', $form_state->getValue('onpoint_path'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
